@@ -790,11 +790,12 @@ class Dataset:
             sheet = workbook.add_worksheet(table.name)
             pointer = Pointer(0, 0)
             for field in table.fields:
-                sheet.write(pointer.row, pointer.col, field, workbook.add_format(table.header_style.attr()))
+                sheet.write(pointer.row, pointer.col, field, workbook.add_format(sheet.header_style.attr()))
                 pointer.next_col()
             pointer.next_row()
             for data_row in table.data_rows:
-                for data in data_row.values():
+                for col in sheet.fields:
+                    data = data_row[col]
                     if isinstance(data.value, datetime.date) \
                             or isinstance(data.value, datetime.time) \
                             or isinstance(data.value, datetime.datetime):
